Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1233)

Unified Diff: third_party/WebKit/Source/platform/scheduler/base/task_queue_impl.h

Issue 2718293003: scheduler: Ensure consistent delayed task ordering between task queues (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/scheduler/base/task_queue_impl.h
diff --git a/third_party/WebKit/Source/platform/scheduler/base/task_queue_impl.h b/third_party/WebKit/Source/platform/scheduler/base/task_queue_impl.h
index 8381157e847d6e1ff1add54fc5fd4e34ebde8da5..3bdc5229f0e04dd1b85fa0c7203ed900fe94a11e 100644
--- a/third_party/WebKit/Source/platform/scheduler/base/task_queue_impl.h
+++ b/third_party/WebKit/Source/platform/scheduler/base/task_queue_impl.h
@@ -177,9 +177,12 @@ class BLINK_PLATFORM_EXPORT TaskQueueImpl final : public TaskQueue {
}
// Enqueues any delayed tasks which should be run now on the
- // |delayed_work_queue|. Returns the deadline if a subsequent wakeup is
- // required. Must be called from the main thread.
- base::Optional<base::TimeTicks> WakeUpForDelayedWork(LazyNow* lazy_now);
+ // |delayed_work_queue|. Returns true and fills |out_next_wake_up_time| and
+ // |out_next_wake_up_sequence_num| if a subsequent wakeup is required. Must be
+ // called from the main thread.
+ bool WakeUpForDelayedWork(LazyNow* lazy_now,
+ base::TimeTicks* out_next_wake_up_time,
altimin 2017/03/01 11:23:17 Nit: time ticks and sequence number seem related.
Sami 2017/03/01 12:17:42 The other option I considered was to just return a
+ int* out_next_wake_up_sequence_num);
base::TimeTicks scheduled_time_domain_wakeup() const {
return main_thread_only().scheduled_time_domain_wakeup;

Powered by Google App Engine
This is Rietveld 408576698